# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-JSON-XS
Summary:	JSON serializing/de-serializing, done correctly and fast
Epoch:		1
Version:	4.03
Release:	9.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/JSON-XS
Source0:	https://cpan.metacpan.org/modules/by-module/JSON/JSON-XS-%{version}.tar.gz
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Canary::Stability)
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(common::sense)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(Types::Serialiser)
BuildRequires:	perl(XSLoader)
# Script Runtime
BuildRequires:	perl(Getopt::Long)
BuildRequires:	perl(Storable)
BuildRequires:	perl(strict)
# Test Suite
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(Encode)
BuildRequires:	perl(Test)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Tie::Array)
BuildRequires:	perl(Tie::Hash)
BuildRequires:	perl(utf8)
BuildRequires:	perl(warnings)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

# Avoid unwanted provides and dependencies (rpm 4.9 onwards)
%{?perl_default_filter}

%description
This module converts Perl data structures to JSON and vice versa. Its
primary goal is to be correct and its secondary goal is to be fast. To
reach the latter goal it was written in C.

%prep
%setup -q -n JSON-XS-%{version}

# Fix shellbangs
perl -pi -e 's|^#!/opt/bin/perl|#!/usr/bin/perl|' eg/*

# Avoid doc-file dependencies
chmod -c -x eg/*

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license COPYING
%doc Changes README eg/
%{_bindir}/json_xs
%{perl_vendorarch}/auto/JSON/
%{perl_vendorarch}/JSON/
%{_mandir}/man1/json_xs.1*
%{_mandir}/man3/JSON::XS.3*
%{_mandir}/man3/JSON::XS::Boolean.3*

%changelog
* Tue Apr 25 2023 Paul Howarth <paul@city-fan.org> - 1:4.03-9
- Use SPDX-format license tag

* Wed Jun  1 2022 Paul Howarth <paul@city-fan.org> - 1:4.03-7
- Perl 5.36 rebuild

* Sat May 22 2021 Paul Howarth <paul@city-fan.org> - 1:4.03-4
- Perl 5.34 rebuild

* Wed Oct 28 2020 Paul Howarth <paul@city-fan.org> - 1:4.03-1
- Update to 4.03
  - When parsing comments in relaxed mode, JSON::XS would detect garbage after
    the JSON text if the comment is after the end and does not end in a
    newline

* Fri Jun 26 2020 Paul Howarth <paul@city-fan.org> - 1:4.02-5
- Perl 5.32 rebuild

* Sat Jun  1 2019 Paul Howarth <paul@city-fan.org> - 1:4.02-2
- Perl 5.30 rebuild

* Wed Mar  6 2019 Paul Howarth <paul@city-fan.org> - 1:4.02-1
- Update to 4.02
  - Undo the fix from 4.01, which breaks more things than it fixes
  - Try a proper fix this time

* Mon Feb 25 2019 Paul Howarth <paul@city-fan.org> - 1:4.01-1
- Update to 4.01
  - Fix some stack corruption caused mostly when calling methods in list
    context

* Tue Nov 20 2018 Paul Howarth <paul@city-fan.org> - 1:4.0-1
- Update to 4.0
  - SECURITY IMPLICATION: this release enables allow_nonref by default for
    compatibility with RFC 7159 and newer; see "old" vs. "new" JSON under
    SECURITY CONSIDERATIONS
  - Reworked the "old" vs. "new" JSON section
  - Add ->boolean_values to provide the values to which booleans decode
  - decode would wrongly accept ASCII NUL characters instead of reporting them
    as trailing garbage
  - Work around what smells like a perl bug w.r.t. exceptions thrown in
    callbacks
  - Incremental parser now more or less respects allow_nonref
  - json_xs json-pretty now enables canonical mode
  - Add documentation section about I-JSON
  - Minor documentation fixes/updates

* Thu Jun 28 2018 Paul Howarth <paul@city-fan.org> - 1:3.04-4
- Perl 5.28 rebuild

* Thu Aug 17 2017 Paul Howarth <paul@city-fan.org> - 1:3.04-1
- Update to 3.04
  - Change exponential realloc algorithm on encoding and string decoding to be
    really exponential (this helps slow/debugging allocators such as libumem)
  - String encoding would needlessly overallocate output space
  - Be very paranoid about extending buffer lengths and croak if buffers get
    too large, which might (or might not) improve security
  - Add cbor-packed type to json_xs
  - Switch from YAML to YAML::XS in json_xs, as YAML is way too buggy and
    outdated

* Mon Aug  7 2017 Paul Howarth <paul@city-fan.org> - 1:3.03-6
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Sun Jun 11 2017 Paul Howarth <paul@city-fan.org> - 1:3.03-4
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally

* Thu Nov 17 2016 Paul Howarth <paul@city-fan.org> - 1:3.03-1
- Update to 3.03
  - Fix a bug introduced by a perl bug workaround that would cause incremental
    parsing to fail with an sv_chop panic
  - json_xs: toformat failure error message fixed
  - json_xs: Allow cyclic data structures in CBOR

* Mon May 16 2016 Paul Howarth <paul@city-fan.org> - 1:3.02-2
- BR: perl-generators where possible
- Simplify find commands using -empty and -delete

* Sat Feb 27 2016 Paul Howarth <paul@city-fan.org> - 1:3.02-1
- Update to 3.02
  - allow_nonref now affects booleans (\1, $Types::Serialiser::Boolean) as well
  - Allow literal tabs in strings in relaxed mode
  - Support "cbor" format in json_xs tool
  - Support (and fix) calling encode and decode in list context
  - Work around a bug in older perls crashing when presented with shared hash
    keys
  - Use stability canary
- Classify buildreqs by usage

* Fri Aug 29 2014 Paul Howarth <paul@city-fan.org> - 1:3.01-4
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Tue Oct 29 2013 Paul Howarth <paul@city-fan.org> - 1:3.01-1
- Update to 3.01
  - Backport to perls < 5.16
- Drop upstreamed compatibility patch

* Tue Oct 29 2013 Paul Howarth <paul@city-fan.org> - 1:3.0-1
- Update to 3.0
  - Implemented an object tagging extension (using the Types::Serialiser
    serialisation protocol)
  - Reworked the documentation regarding object serialisation, adding a new
    OBJECT SERIALISATION section that explains the whole process
  - New setting: allow_tags
  - Switch to Types::Serialiser booleans
  - Remove to_json/from_json
  - Other minor improvements to the documentation
- Remove provides filter following major version bump
- Specify all dependencies
- Add patch for compatibility with perl < 5.16

* Tue Jul 16 2013 Paul Howarth <paul@city-fan.org> - 1:2.34-2
- Perl 5.18 rebuild

* Sat May 25 2013 Paul Howarth <paul@city-fan.org> - 1:2.34-1
- Update to 2.34
  - Handle hash randomization in perl 5.18
  - When canonicalising, only allocate up to 64 hash key pointers on the stack;
    for larger hashes, use the heap, to avoid using too much stack space
  - Discuss the problem with setlocale

* Thu Aug  2 2012 Paul Howarth <paul@city-fan.org> - 1:2.33-1
- Update to 2.33
  - Internal encode/decode XS wrappers did not expect stack moves caused by
    callbacks
  - Add bencode as to/from option in bin/json_xs
  - Add -e option to json_xs, and none and string in/out formats

* Fri Jun 22 2012 Paul Howarth <paul@city-fan.org> - 1:2.32-2
- BR: perl(Data::Dumper), perl(Encode), perl(Test)
- Install to vendor directories
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Drop rpath-avoidance kludge
  - Don't need to define %%{perl_vendorarch}
  - Use %%{_fixperms} macro rather than our own chmod incantation
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Thu Aug 11 2011 Paul Howarth <paul@city-fan.org> - 1:2.32-1
- Update to 2.32:
  - Fix a bug in the initial whitespace accumulation

* Wed Jul 27 2011 Paul Howarth <paul@city-fan.org> - 1:2.31-1
- Update to 2.31:
  - Don't accumulate initial whitespace in the incremental buffer (this can be
    useful to allow whitespace-keepalive on a tcp connection without triggering
    the max_size limit)
  - Properly croak on some invalid inputs that are not strings (e.g. undef)
    when trying to decode a JSON text

* Tue Jun 28 2011 Paul Howarth <paul@city-fan.org> - 1:2.30-3
- Rebuild for perl 5.14.1 in Rawhide
- Tweak provides filter not to conflict with new Fedora macros
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Jan 28 2011 Paul Howarth <paul@city-fan.org> - 1:2.30-2
- Import from Fedora

* Mon Oct 11 2010 Marcela Mašláňová <mmaslano@redhat.com> - 1:2.30-1
- Update

* Sun May 02 2010 Marcela Maslanova <mmaslano@redhat.com> - 1:2.27-2
- Mass rebuild with perl 5.12.0

* Sat Feb 27 2010 Chris Weyl <cweyl@alumni.drew.edu> - 1:2.27-1
- Update by Fedora::App::MaintainerTools 0.004
- PERL_INSTALL_ROOT => DESTDIR
- Added a new br on perl(common::sense) (version 0)
- Added a new req on perl(common::sense) (version 0)

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 1:2.24-3
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:2.24-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Jun 02 2009 Chris Weyl <cweyl@alumni.drew.edu> - 1:2.24-1
- Auto-update to 2.24 (by cpan-spec-update 0.01)

* Thu Mar 26 2009 Chris Weyl <cweyl@alumni.drew.edu> - 2.2311-4
- Stripping bad provides of private Perl extension libs

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2311-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2311-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Feb 22 2009 Chris Weyl <cweyl@alumni.drew.edu> - 2.2311-1
- Update to 2.2311

* Sun Sep 07 2008 Chris Weyl <cweyl@alumni.drew.edu> - 2.2222-1
- Update to the increasingly silly version of 2.2222
- Update files to include bin

* Wed Jun 25 2008 Chris Weyl <cweyl@alumni.drew.edu> - 2.21-1
- Update to 2.21

* Wed May 28 2008 Chris Weyl <cweyl@alumni.drew.edu> - 2.2-1
- Update to 2.2

* Sun Mar 09 2008 Chris Weyl <cweyl@alumni.drew.edu> - 2.01-1
- Update to 2.x series before F9

* Thu Mar 06 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.52-3
- Rebuild for new perl

* Mon Feb 18 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.52-2
- Autorebuild for GCC 4.3

* Wed Oct 17 2007 Chris Weyl <cweyl@alumni.drew.edu> - 1.52-1
- Update to 1.52
- License tag update: GPL -> GPL+

* Tue Aug 21 2007 Chris Weyl <cweyl@alumni.drew.edu> - 1.43-2
- Bump

* Thu Aug 09 2007 Chris Weyl <cweyl@alumni.drew.edu> - 1.43-1
- Update to 1.43

* Fri Jun 01 2007 Chris Weyl <cweyl@alumni.drew.edu> - 1.22-1
- Update to 1.22

* Mon May 14 2007 Chris Weyl <cweyl@alumni.drew.edu> - 1.21-3
- Bump

* Mon May 14 2007 Chris Weyl <cweyl@alumni.drew.edu> - 1.21-2
- Add eg/ to doc

* Sun May 13 2007 Chris Weyl <cweyl@alumni.drew.edu> - 1.21-1
- Specfile autogenerated by cpanspec 1.71
